@@ -15,8 +15,8 @@ def __parse_version(v):                                       # pragma: nocover
     return ver, rel, ver_info
 
 
-__version__ = "0.8.5"
-__release_name__ = "30$ Bag"
+__version__ = "0.8.8"
+__release_name__ = "In Ruins"
 __years__ = "2002-2018"
 
 _, __release__, __version_info__ = __parse_version(__version__)
