@@ -216,6 +216,7 @@ class Frame(object):
 
     def _initEncoding(self):
         assert(self.header.version and len(self.header.version) == 3)
+        curr_enc = self.encoding
 
         if self.encoding is not None:
             # Make sure the encoding is valid for this version
@@ -235,6 +236,9 @@ class Frame(object):
             else:
                 self.encoding = UTF_8_ENCODING
 
+        log.debug("_initEncoding: was={} now={}".format(curr_enc,
+                                                        self.encoding))
+
     @property
     def encoding(self):
         return self._encoding
@@ -585,7 +589,7 @@ class ImageFrame(Frame):
             self.picture_type = pt
         log.debug("APIC picture type: %d" % self.picture_type)
 
-        self.desciption = u""
+        self.description = u""
 
         # Remaining data is a NULL separated description and image data
         buffer = input.read()
