@@ -39,7 +39,7 @@ class TestDisplayPlugin(unittest.TestCase):
         self.__checkOutput(u"%C% - %composer%", u"Bad Brains - Bad Brains")
 
     def testCommentsTag(self):
-        self.file.tag.comments.set(u"TEXT", description=None, lang=b"DE")
+        self.file.tag.comments.set(u"TEXT", description=u"", lang=b"DE")
         self.file.tag.comments.set(u"#d-tag", description=u"#l-tag", lang=b"#t-tag")
         # Langs are chopped to 3 bytes (are are codes), so #t- is expected.
         self.__checkOutput(u"%comments,output=#d #l #t,separation=|%", u" DE TEXT|#l-tag #t- #d-tag")
